@@ -259,6 +259,10 @@ int arch_finalize_section_address (struct obj_file *f, ElfW(Addr) base);
 
 int arch_archdata (struct obj_file *fin, struct obj_section *sec);
 
+#ifndef arch_module_base
+#define arch_module_base(m) ((ElfW(Addr))0)
+#endif
+
 #define ARCHDATA_SEC_NAME "__archdata"
 
 /* Pointers in objects can be 32 or 64 bit */
